# Estimate BPR curves by ecoregion
# (C) Jingjing Liang 2018

library(nlme)

# Load plot-level data
# Download GFB1_data_figshare.xlxs from Figshare and convert to a csv file

data<- read.csv("GFB1_data_figshare.csv")
data <- subset(data, P>0)
data <- subset(data, S>0)
attach(data)


## Montane Grass and shrubs ##

data1 <- subset(data, data$Ecoregion==10 | data$ Ecoregion ==9 | data$Ecoregion ==8)
data1 <- subset(data1,data1$P<=quantile(data1$P,0.999))


############## BPR Estimation #####################

############ Bootstrapping ##################
coef <- matrix(0, nrow=50, ncol=101)	# Coef Matrix	


for(i in 1: 50) {
  tryCatch({

	training <- data1[sample(1:nrow(data1), 23133, replace=TRUE),]
	logP <- log(training$P)
	
	Lat1 <- training$Lat + rnorm(length(training$Lat))
	Lon1 <- training$Lon + rnorm(length(training$Lon))
	training <- cbind(training, logP, Lat1, Lon1)
	
	S_max <- max(training$S)
	SR <- training$S/S_max*100
	
	logS <- log(SR)
	training <- cbind(training, logS)

	lm1 <- lm(logP~ logS + G + T3 + C1 + C3 + PET + IAA + E, data=training)

	# Derive ceteris paribus BPR curve
	newdata <- data.frame(logS=log(seq(1,100,1)), G=mean(training$G),T3=mean(training$T3), C1=mean(training$C1), C3=mean(training$C3),PET=mean(training$PET), IAA=mean(training$IAA), E=mean(training$E))
	coef[i,1]  <-coef(lm1)[2]               #theta
	coef[i,2:101]   <- exp(predict(lm1,newdata))
  plot(coef[i,])
	#counter
	cat(i, " of ", 50, date(), "\n" )

	#remove files
	rm(training, newdata, gls1)

  }, error=function(e){})
	}

coef_df <- as.data.frame(coef)

write.csv(coef_df, "Ecoregion_Grasslands_BPR.csv")

# Plot mean and 95% CI of bootstrapping
plot(seq(1,100,1),colMeans(coef_df[,2:101]), ylim=c(0,6), type="l",col = "blue", ylab="P",xlab="S_relative")
# Confidence interval
lines(seq(1,100,1),colMeans(coef_df[,2:101])+1.96*apply(coef_df[,2:101], 2, sd), ylim=c(5,8), type="l",col = "red")
lines(seq(1,100,1),colMeans(coef_df[,2:101])-1.96*apply(coef_df[,2:101], 2, sd), ylim=c(5,8), type="l",col = "red")


# End of the code
